<p align="center">
  <i>Framework de evaluación de sistemas de Generación Mejorada por Recuperación (GMR)</i>
</p>

<h4 align="center">
    <p>
        <a href="#instalación">Instalación</a> |
        <a href="#ejemplo-de-uso">Ejemplo de uso</a> |
        <a href="#contacto">Contacto</a> |
        <a href="https://huggingface.co/PrevenIA">Hugging Face</a>
    <p>
</h4>

> Explicación somera sobre una librería que como objetivo ostenta evaluar sistemas de generación mejorada por recuperación.

## Instalación

```bash
pip install TODO
```

## Ejemplo de uso

TODO

```python
TODO
```

## Contacto

paascorb@unirioja.es